Imports System.IO.Ports


Friend Class Form_Main
    Inherits System.Windows.Forms.Form

    Private EventsAreEnabled As Boolean = False
    Private WithEvents comPort As New SerialPort()
    Friend PortNumber As Int32

    Private Sub MainForm_Load(ByVal eventSender As System.Object, _
                              ByVal eventArgs As System.EventArgs) Handles MyBase.Load
        '
        EventsAreEnabled = False
        '
        Me.Text = AppTitleAndVersion("Theremino Bridge")
        '
        MemoryMappedFile_Init()
        ' --------------------------------------- default PORT number
        PortNumber = 1
        ' ---------------------------------------
        Load_INI()
        EnableDisableLog()
        ' --------------------------------------- Set the combo with the port number
        cmb_PortNumber.SelectedIndex = PortNumber - 1
        ' --------------------------------------- Auto-connect at start
        Connect_ComPort()
        '
        EventsAreEnabled = True
    End Sub

    Private Sub MainForm_FormClosed(ByVal eventSender As System.Object, _
                                    ByVal eventArgs As System.Windows.Forms.FormClosedEventArgs) _
                                    Handles Me.FormClosed
        Disconnect_ComPort()
        Save_INI()
    End Sub


    ' ================================================================================================
    '  Controls
    ' ================================================================================================
    Private Sub cmd_Connect_Click(ByVal eventSender As System.Object, _
                                  ByVal eventArgs As System.EventArgs) Handles cmd_Connect.Click
        cmd_Connect.Visible = True
        cmd_Disconnect.Visible = False
        Connect_ComPort()
    End Sub
    Private Sub cmd_Disconnect_Click(ByVal eventSender As System.Object, _
                                     ByVal eventArgs As System.EventArgs) Handles cmd_Disconnect.Click
        cmd_Connect.Visible = True
        cmd_Disconnect.Visible = False
        Disconnect_ComPort()
    End Sub
    Private Sub cmb_PortNumber_SelectedIndexChanged(ByVal sender As System.Object, _
                                                    ByVal e As System.EventArgs) Handles cmb_PortNumber.SelectedIndexChanged
        If Not EventsAreEnabled Then Return
        Connect_ComPort()
    End Sub
    Private Sub chk_ShowLog_CheckedChanged(ByVal sender As System.Object, _
                                           ByVal e As System.EventArgs) Handles chk_ShowLog.CheckedChanged
        If Not EventsAreEnabled Then Return
        EnableDisableLog()

    End Sub
    Private Sub EnableDisableLog()
        If chk_ShowLog.Checked Then
            Me.MinimumSize = New Size(640, 320)
            Me.Size = Me.MinimumSize
            Me.FormBorderStyle = Windows.Forms.FormBorderStyle.Sizable
        Else
            Me.MinimumSize = New Size(500, 80)
            Me.Size = Me.MinimumSize
            Me.FormBorderStyle = Windows.Forms.FormBorderStyle.FixedSingle
        End If
    End Sub


    ' ================================================================================================
    '  Connect - Disconnect - Receive
    ' ================================================================================================
    Private Sub Connect_ComPort()
        ' -------------------------------------------- If the port is Open then close it
        Disconnect_ComPort()
        ' -------------------------------------------- Set PORT and SPEED
        comPort.PortName = "COM" & (cmb_PortNumber.SelectedIndex + 1).ToString
        comPort.BaudRate = 9600
        comPort.Parity = Parity.None
        comPort.DataBits = 8
        comPort.StopBits = StopBits.One
        ' -------------------------------------------- Set params
        'comPort.InputLen = 5 '(no equivalent in VbNet)
        comPort.ReceivedBytesThreshold = 1
        comPort.ReadBufferSize = 5000
        ' -------------------------------------------- Disable DTR
        comPort.DtrEnable = False
        ' -------------------------------------------- Try to open the port
        Try
            comPort.Open()
        Catch
        End Try
        ' -------------------------------------------- Test if the port is really open
        If comPort.IsOpen Then
            cmd_Disconnect.Visible = True
            cmd_Connect.Visible = False
        Else
            cmd_Disconnect.Visible = False
            cmd_Connect.Visible = True
        End If
    End Sub

    Private Sub Disconnect_ComPort()
        If comPort.IsOpen Then
            comPort.Close()
        End If
    End Sub

    ' ----------------------------------------------------------------------------------------
    '  Receive from serial a 5 character number from 0 to 65535 terminated with a LineFeed
    ' ----------------------------------------------------------------------------------------
    Private Sub comPort_DataReceived(ByVal sender As Object, _
                                     ByVal e As System.IO.Ports.SerialDataReceivedEventArgs) _
                                     Handles comPort.DataReceived

        Dim s As String = comPort.ReadExisting
        ' ---------------------------------------- send Alessio data type ending with LineFeed to slot 0
        If s.EndsWith(vbLf) Then
            WriteSlot(0, CSng(Val(s)))
        End If
        ' ---------------------------------------- visualize ASCII and HEX TextBoxes
        If chk_ShowLog.Checked Then
            Me.Invoke(New Action(Of String)(AddressOf UpdateTextBox), s)
        End If
    End Sub

    Private Sub UpdateTextBox(ByVal s As String)
        TextBox1.Text &= s.Replace(vbCr, ".")
        For i As Int32 = 1 To s.Length
            TextBox2.Text &= Asc(Mid(s, i, 1)).ToString("00") & " "
        Next
    End Sub

End Class